Changelog
=========

0.12.0 (2022-06-14)
-------------------

* Added changelog
* Dropped supported for Django 2.2
* Added initial DMN functionality

    * Implement evaluating a DMN table by ID or key
    * Implement introspecing a DMN table by ID or key

* Exposed types
* Improved type hints
